@@ -14,7 +14,7 @@ import os, shutil, string, sys, time
 class Mooi:
 	DIR = os.path.expandvars('${HOME}/Lavengro')
 	LRC = os.path.expandvars(DIR + os.sep + 'lavengrorc')
-	HDR = "\nLavengro - The Word Master - Ver. 1.1.4\n" +\
+	HDR = "\nLavengro - The Word Master - Ver. 1.1.7\n" +\
 		  "-- Enter 'q' at any time to quit --\n"
 	SUB =  "(Available subjects) - 'q' to quit"
 	MODE = ['lavengro - programmed learning',
@@ -53,7 +53,7 @@ class Mooi:
 		for i in range(len(lines)-1,0,-1):
 			if (string.strip(lines[i]) == ''):
 				lines = lines[:-1]
-			else:						# (4)
+			else:			
 				break
 		return lines
 
@@ -123,15 +123,22 @@ class Mooi:
 
 	# get quiz in lavengro mode, choosing dir then file
 	def selectQuiz(self):
-		self.prevUsrChoice = -1			# (5)
+		self.prevUsrChoice = -1	
 
 		if (self.modes[3]):
 			self.bsdMode()
-			return						# (5)
+			return			
 
 		if (self.modes[0]):
 			if ((self.tests != None) and (len(self.tests) != 0)):
-				self.quiz = [ self.prefix + self.tests.pop(), 0, 1]
+				next = self.tests.pop()
+				if (next in self.scored):
+					self.modes[1] = 1
+					self.modes[2] = 0
+				else:
+					self.modes[1] = 0 
+					self.modes[2] = 1
+				self.quiz = [ self.prefix + next, 0, 1]
 				return
 			elif ((self.tests != None) and (len(self.tests) == 0)):
 				self.exit('All tests taken.', 0)
@@ -141,7 +148,7 @@ class Mooi:
 		files = os.listdir(self.DIR)
 		for file in files:
 			if ((os.path.isdir(self.DIR + os.sep + file)) and
-				(file != 'py')):		# (3)
+				(file != 'py')):
 				dirs.append(file)
 		print self.SUB
 		choice = self.query(dirs, 'Choose subject: ')
@@ -195,7 +202,7 @@ class Mooi:
 
 	def loadLav(self):
 		if (os.path.exists(self.record)):
-			shutil.copyfile(self.record, self.record + '.safe') # (10)
+			shutil.copyfile(self.record, self.record + '.safe')
 			self.lav = open(self.record, 'r')
 			lines = self.lav.readlines()
 			self.lav.close()
@@ -208,7 +215,7 @@ class Mooi:
 
 	# get quiz in bsd mode, choosing file, questions, and answers
 	def bsdMode(self):
-		self.quiz = []					# (5)
+		self.quiz = []	
 		# get bsd index
 		f = open(self.DIR + os.sep + 'index')
 		lines = f.readlines()
@@ -255,7 +262,7 @@ class Mooi:
 		# cat '\' continued lines
 		for line in lines:
 			if (line[0] == '#'):
-				continue				# (6)
+				continue	
 			line = string.strip(line)
 			tmplist = list(line)
 			tmpline = tmpline + line
@@ -316,7 +323,7 @@ class Mooi:
 			score = round( ((correct * 100) / self.total), 0)
 			print '\nScore: ' + `score` + '%\n'
 			if (self.lav != None):
-				if (score > 80):		# (2)
+				if (score > 80):
 					self.purge_pending(name)
 					self.pending.append(name + ':*SCORE*:' + `score` + '\n')
 				else:
